@@ -3,10 +3,9 @@ from django import http
 from django.conf import settings
 
 class RedirectFallbackMiddleware(object):
-    def process_response(self, request, response):
-        if response.status_code != 404:
-            return response # No need to check for a redirect for non-404 responses.
-        path = request.get_full_path()
+    def process_exception(self, request, exception):
+        if isinstance(exception, http.Http404):
+            path = request.get_full_path()
         try:
             r = CMSRedirect.objects.get(site__id__exact=settings.SITE_ID, old_path=path)
         except CMSRedirect.DoesNotExist:
@@ -25,5 +24,3 @@ class RedirectFallbackMiddleware(object):
                 return http.HttpResponseGone()
             return http.HttpResponsePermanentRedirect(r.new_path)
 
-        # No redirect was found. Return the response.
-        return response
